@@ -3,9 +3,9 @@ from bluedot_rest_framework import import_string
 from bluedot_rest_framework.utils.serializers import CustomSerializer
 
 
-EventSpeaker = import_string('EVENT.speaker.models')
-EventSpeakerSerializer = import_string('EVENT.speaker.serializers')
-EventSchedule = import_string('EVENT.schedule.models')
+EventSpeaker = import_string('event.speaker.models')
+EventSpeakerSerializer = import_string('event.speaker.serializers')
+EventSchedule = import_string('event.schedule.models')
 
 
 class EventScheduleSerializer(CustomSerializer):
