@@ -15,15 +15,25 @@ class FilterBackend:
                     if key == 'time_state':
                         queryset = self.get_time_state(
                             key, field_value, filterset_fields[key], queryset)
+                    elif key == 'category_id':
+                        queryset = self.get_category_id(
+                            field_value, filterset_fields, queryset)
+
                     else:
                         _filter = filterset_fields[key]
-                        if _filter['lookup_expr'] == 'in':
-                            field_value = self.filter_in(_filter, field_value)
+                        if _filter['lookup_expr'] == '__in':
+                            field_value = self.filter_in(
+                                _filter, field_value)
                         elif _filter['field_type'] == 'bool':
                             field_value = self.filter_bool(field_value)
                         lookup_type = key + _filter['lookup_expr']
                         queryset = queryset.filter(
                             **{lookup_type: field_value})
+
+        return queryset
+
+    def get_category_id(self, field_value, filterset_field, queryset):
+        queryset = queryset.filter(category_id__contains=int(field_value))
         return queryset
 
     def get_time_state(self, key, field_value, filterset_field, queryset):
