@@ -77,7 +77,10 @@ class WeChatUserSet:
             self.update_user()
         else:
             self.create_user()
-
+    def handle_subscribe(self,subscribe):
+        if self.wechat_user_queryset:
+            self.wechat_user_queryset.subscribe=subscribe
+ 
     def get_token(self):
         token = ''
         if self.wechat_user_queryset:
