@@ -2,7 +2,7 @@ from bluedot_rest_framework.utils.models import models, AbstractRelationTime
 
 
 class WeChatUser(AbstractRelationTime):
-    unionid = models.CharField(max_length=32)
+    unionid = models.CharField(max_length=32,null=True)
     nick_name = models.CharField(max_length=100, verbose_name='昵称')
     gender = models.IntegerField(verbose_name='性别')
     language = models.CharField(max_length=32, verbose_name='语言')
