@@ -1,6 +1,6 @@
 from rest_framework.serializers import CharField
 from bluedot_rest_framework.utils.serializers import CustomSerializer
-from .models import WeChatResponseMaterial, WeChatResponseEvent
+from .models import WeChatResponseMaterial, WeChatResponseEvent, WeChatQrcode
 
 
 class WeChatResponseMaterialSerializer(CustomSerializer):
@@ -21,3 +21,10 @@ class WeChatResponseEventSerializer(CustomSerializer):
     class Meta:
         model = WeChatResponseEvent
         fields = '__all__'
+
+
+class WeChatQrcodeSerializer(CustomSerializer):
+
+    class Meta:
+        model = WeChatQrcode
+        fields = '__all__'
